mysql.stmt.bind_in.Input_Stream

Package mysql :: Package stmt :: Module bind_in :: Class Input_Stream |
[hide private]
[frames] | no frames]

# Class Input_Stream

    object --+
             |
            Input_Stream

Input Stream.

This is the object placed into your input binding that relays data to MySQL.

Instance Methods | [hide private]
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
`` | write(...) Write data to the input stream.
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e560>`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: object.__new__

### write(...) |
Write data to the input stream. Note This will close any live unbuffered result objects and reset any live statement objects. Parameters: `data` - A string of data to write. Raises: `mysql.exceptions.MySQL_Error` - Generic MySQL error. `OverflowError` - The amount of data would exceed the column's maximum size.

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e560>